==> jdk-11.0.8_linux-x64_bin.tar.gz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_bm.java <==
/*
 * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_bm extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "arabu mara kafoli Diram" },
            { "aoa", "angola Kwanza" },
            { "aud", "ositirali Dolar" },
            { "bhd", "bareyini Dinar" },
            { "bif", "burundi Fra\u014b" },
            { "bwp", "b\u0254tisiwana Pula" },
            { "cad", "kanada Dolar" },
            { "cdf", "kongole Fra\u014b" },
            { "chf", "suwisi Fra\u014b" },
            { "cny", "siniwa Yuwan" },
            { "cve", "capiv\u025brdi Esekudo" },
            { "djf", "jibuti Fra\u014b" },
            { "dzd", "alizeri Dinar" },
            { "egp", "eziputi Livri" },
            { "ern", "eritere Nafika" },
            { "etb", "etiopi Bir" },
            { "eur", "ero" },
            { "gbp", "angil\u025b Livri" },
            { "ghc", "gana Sedi" },
            { "gmd", "gambi Dalasi" },
            { "gns", "gine Fra\u014b" },
            { "inr", "\u0190ndu Rupi" },
            { "jpy", "zap\u0254ne Y\u025bn" },
            { "kes", "keniya Siling" },
            { "kmf", "kom\u0254ri Fra\u014b" },
            { "lrd", "liberiya Dolar" },
            { "lsl", "lesoto Loti" },
            { "lyd", "libi Dinar" },
            { "mad", "mar\u0254ku Diram" },
            { "mga", "madagasikari Fra\u014b" },
            { "mro", "m\u0254ritani Uguwiya (1973\u20132017)" },
            { "mru", "m\u0254ritani Uguwiya" },
            { "mur", "morisi Rupi" },
            { "mwk", "malawi Kwaca" },
            { "mzm", "mozanbiki Metikali" },
            { "nad", "namibi Dolar" },
            { "ngn", "nizeriya N\u025bra" },
            { "rwf", "ruwanda Fra\u014b" },
            { "sar", "sawudiya Riyal" },
            { "scr", "ses\u025bli Rupi" },
            { "sdg", "sudani Dinar" },
            { "sdp", "sudani Livri" },
            { "shp", "\u0190l\u025bni-Senu Livri" },
            { "sll", "siyeralew\u0254ni Lew\u0254ni" },
            { "sos", "somali Siling" },
            { "std", "sawotome Dobra (1977\u20132017)" },
            { "stn", "sawotome Dobra" },
            { "szl", "swazilandi Lilangeni" },
            { "tnd", "tunizi Dinar" },
            { "tzs", "tanzani Siling" },
            { "ugx", "uganda Siling" },
            { "usd", "ameriki Dolar" },
            { "xaf", "sefa Fra\u014b (BEAC)" },
            { "xof", "sefa Fra\u014b (BCEAO)" },
            { "zar", "sudafriki Randi" },
            { "zmk", "zambi Kwaca (1968\u20132012)" },
            { "zmw", "zambi Kwaca" },
            { "zwd", "zimbabuwe Dolar" },
        };
        return data;
    }
}

==> jdk-24.0.1_linux-x64_bin.tar.gz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_bm.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_bm extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "aed", "arabu mara kafoli Diram" },
            { "aoa", "angola Kwanza" },
            { "aud", "ositirali Dolar" },
            { "bhd", "bareyini Dinar" },
            { "bif", "burundi Fra\u014b" },
            { "bwp", "b\u0254tisiwana Pula" },
            { "cad", "kanada Dolar" },
            { "cdf", "kongole Fra\u014b" },
            { "chf", "suwisi Fra\u014b" },
            { "cny", "siniwa Yuwan" },
            { "cve", "capiv\u025brdi Esekudo" },
            { "djf", "jibuti Fra\u014b" },
            { "dzd", "alizeri Dinar" },
            { "egp", "eziputi Livri" },
            { "ern", "eritere Nafika" },
            { "etb", "etiopi Bir" },
            { "eur", "ero" },
            { "gbp", "angil\u025b Livri" },
            { "ghc", "gana Sedi" },
            { "gmd", "gambi Dalasi" },
            { "gns", "gine Fra\u014b" },
            { "inr", "\u0190ndu Rupi" },
            { "jpy", "zap\u0254ne Y\u025bn" },
            { "kes", "keniya Siling" },
            { "kmf", "kom\u0254ri Fra\u014b" },
            { "lrd", "liberiya Dolar" },
            { "lsl", "lesoto Loti" },
            { "lyd", "libi Dinar" },
            { "mad", "mar\u0254ku Diram" },
            { "mga", "madagasikari Fra\u014b" },
            { "mro", "m\u0254ritani Uguwiya (1973\u20132017)" },
            { "mru", "m\u0254ritani Uguwiya" },
            { "mur", "morisi Rupi" },
            { "mwk", "malawi Kwaca" },
            { "mzm", "mozanbiki Metikali" },
            { "nad", "namibi Dolar" },
            { "ngn", "nizeriya N\u025bra" },
            { "rwf", "ruwanda Fra\u014b" },
            { "sar", "sawudiya Riyal" },
            { "scr", "ses\u025bli Rupi" },
            { "sdg", "sudani Dinar" },
            { "sdp", "sudani Livri" },
            { "shp", "\u0190l\u025bni-Senu Livri" },
            { "sle", "siyeralew\u0254ni Lew\u0254ni" },
            { "sll", "siyeralew\u0254ni Lew\u0254ni (1964\u20142022)" },
            { "sos", "somali Siling" },
            { "std", "sawotome Dobra (1977\u20132017)" },
            { "stn", "sawotome Dobra" },
            { "szl", "swazilandi Lilangeni" },
            { "tnd", "tunizi Dinar" },
            { "tzs", "tanzani Siling" },
            { "ugx", "uganda Siling" },
            { "usd", "ameriki Dolar" },
            { "xaf", "sefa Fra\u014b (BEAC)" },
            { "xof", "sefa Fra\u014b (BCEAO)" },
            { "zar", "sudafriki Randi" },
            { "zmk", "zambi Kwaca (1968\u20132012)" },
            { "zmw", "zambi Kwaca" },
            { "zwd", "zimbabuwe Dolar" },
        };
        return data;
    }
}
